@@ -647,6 +647,30 @@ func (c *Config) applyArgs(
 	return nil
 }
 
+// checkVersion checks that chezmoi is at least the required version for the
+// source state.
+func (c *Config) checkVersion() error {
+	versionAbsPath := c.SourceDirAbsPath.JoinString(chezmoi.VersionName)
+	switch data, err := c.baseSystem.ReadFile(versionAbsPath); {
+	case errors.Is(err, fs.ErrNotExist):
+	case err != nil:
+		return err
+	default:
+		minVersion, err := semver.NewVersion(strings.TrimSpace(string(data)))
+		if err != nil {
+			return fmt.Errorf("%s: %q: %w", versionAbsPath, data, err)
+		}
+		var zeroVersion semver.Version
+		if c.version != zeroVersion && c.version.LessThan(*minVersion) {
+			return &chezmoi.TooOldError{
+				Need: *minVersion,
+				Have: c.version,
+			}
+		}
+	}
+	return nil
+}
+
 // cmdOutput returns the of running the command name with args in dirAbsPath.
 func (c *Config) cmdOutput(dirAbsPath chezmoi.AbsPath, name string, args []string) ([]byte, error) {
 	cmd := exec.Command(name, args...)
@@ -852,9 +876,9 @@ func (c *Config) defaultPreApplyFunc(
 		case choice == "skip":
 			return chezmoi.Skip
 		case choice == "quit":
-			return chezmoi.ExitCodeError(1)
+			return chezmoi.ExitCodeError(0)
 		default:
-			return nil
+			panic(fmt.Sprintf("%s: unexpected choice", choice))
 		}
 	}
 }
@@ -1419,6 +1443,10 @@ func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi
 func (c *Config) newSourceState(
 	ctx context.Context, options ...chezmoi.SourceStateOption,
 ) (*chezmoi.SourceState, error) {
+	if err := c.checkVersion(); err != nil {
+		return nil, err
+	}
+
 	httpClient, err := c.getHTTPClient()
 	if err != nil {
 		return nil, err
@@ -1426,25 +1454,6 @@ func (c *Config) newSourceState(
 
 	sourceStateLogger := c.logger.With().Str(logComponentKey, logComponentValueSourceState).Logger()
 
-	versionAbsPath := c.SourceDirAbsPath.JoinString(chezmoi.VersionName)
-	switch data, err := c.baseSystem.ReadFile(versionAbsPath); {
-	case errors.Is(err, fs.ErrNotExist):
-	case err != nil:
-		return nil, err
-	default:
-		minVersion, err := semver.NewVersion(strings.TrimSpace(string(data)))
-		if err != nil {
-			return nil, fmt.Errorf("%s: %q: %w", versionAbsPath, data, err)
-		}
-		var zeroVersion semver.Version
-		if c.version != zeroVersion && c.version.LessThan(*minVersion) {
-			return nil, &chezmoi.TooOldError{
-				Need: *minVersion,
-				Have: c.version,
-			}
-		}
-	}
-
 	c.SourceDirAbsPath, err = c.sourceDirAbsPath()
 	if err != nil {
 		return nil, err
@@ -1718,21 +1727,6 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
-	// Create the runtime directory if needed.
-	if boolAnnotation(cmd, runsCommands) {
-		if runtime.GOOS == "linux" && c.bds.RuntimeDir != "" {
-			// Snap sets the $XDG_RUNTIME_DIR environment variable to
-			// /run/user/$uid/snap.$snap_name, but does not create this
-			// directory. Consequently, any spawned processes that need
-			// $XDG_DATA_DIR will fail. As a work-around, create the directory
-			// if it does not exist. See
-			// https://forum.snapcraft.io/t/wayland-dconf-and-xdg-runtime-dir/186/13.
-			if err := chezmoi.MkdirAll(c.baseSystem, chezmoi.NewAbsPath(c.bds.RuntimeDir), 0o700); err != nil {
-				return err
-			}
-		}
-	}
-
 	// Determine the working tree directory if it is not configured.
 	if c.WorkingTreeAbsPath.Empty() {
 		workingTreeAbsPath := c.SourceDirAbsPath
